"use strict";

var path = require('path');

var fs = require('fs');

var cwd = process.cwd();
var defaultBishengConfigPath = path.resolve(cwd, './bisheng.config.js');
var processArgv = process.argv;

function getBishengConfigPath() {
  for (var i = 0; i < processArgv.length; i++) {
    var item = processArgv[i];
    var index = i;

    if (item === '-c' || item === '--config') {
      var argvConfigPath = processArgv[index + 1];

      if (argvConfigPath) {
        return path.resolve(cwd, argvConfigPath);
      }
    }
  }

  return defaultBishengConfigPath;
}

var bishengConfigPath = getBishengConfigPath();

var bishengConfig = require(bishengConfigPath);

function getSingleRouterConfig(template, _root) {
  var routeConfig = {};

  function getDir() {
    var root = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _root;
    var tem = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : template;
    var f = fs.readdirSync(root);
    f.forEach(function (item) {
      var itemPath = path.join(root, item);
      var state = fs.statSync(itemPath);

      if (state.isDirectory()) {
        getDir(itemPath, tem + "/".concat(item));
      } else {
        var route = tem + "/:childe";
        routeConfig[route] = route;
      }
    });
  }

  getDir();
  return Object.keys(routeConfig).map(function (item) {
    return {
      path: item,
      component: "./template/Article"
    };
  });
}

function getRouterConfig() {
  var routeConfig = [];
  Object.keys(bishengConfig.source).forEach(function (key) {
    var root = path.resolve(cwd, bishengConfig.source[key]);
    routeConfig = routeConfig.concat(getSingleRouterConfig(key, root));
  });
  return routeConfig;
}

function getPick() {
  var pick = {};
  Object.keys(bishengConfig.source).forEach(function (key) {
    pick[key] = function (markdownData) {
      return {
        meta: markdownData.meta,
        description: markdownData.description
      };
    };
  });
  return pick;
}

module.exports = {
  lazyLoad: true,
  pick: getPick(),
  plugins: [path.join(__dirname, '..', 'node_modules', 'bisheng-plugin-description')],
  routes: {
    path: "/",
    component: './template/Layout/index',
    indexRoute: {
      component: './template/BlogLog/index'
    },
    childRoutes: getRouterConfig()
  }
};